@@ -9,6 +9,9 @@ from concurrent import futures
 from ..chat.loop import ChatLoop
 from ..chat.session import ChatSession, Rejected
 
+os.environ['CHAT_HOST'] = 'tinode-server'
+os.environ['CHAT_PORT'] = '16060'
+
 def same_elements_in_lists(list1, list2):
     list1 = list(list1)
     try:
@@ -98,10 +101,13 @@ def simple_decode(b):
 
 @pytest.mark.asyncio
 async def test_p2p_topic_publish(loop):
+    secret_s1 = random_secret()
     async with loop.new_session() as s1, loop.new_session() as s2:
-        await s1.register(random_secret())
+        await s1.register(secret_s1)
         await s2.register(random_secret())
 
+        user_ids = [s1.user_id, s2.user_id]
+
         # s1 can send a message after subscribing
         with pytest.raises(Rejected):
             await s1.publish(s2.user_id, simple_encode('hello'))
@@ -147,6 +153,21 @@ async def test_p2p_topic_publish(loop):
         assert msg.content == echo.content
         assert s2._ChatSession__data_messages.qsize() == 0
 
+        await s2.publish(s1.user_id, simple_encode('ok!'))
+    
+    async with loop.new_session() as s1:
+        await s1.login(secret_s1)
+        await s1.subscribe(user_ids[1])
+        await s1.get_message_history(user_ids[1])
+        messages_aiter = s1.messages()
+
+        from_user_ids = []
+        from_user_ids.append((await messages_aiter.__anext__()).from_user_id)
+        from_user_ids.append((await messages_aiter.__anext__()).from_user_id)
+        from_user_ids.append((await messages_aiter.__anext__()).from_user_id)
+
+        assert set(user_ids) == set(from_user_ids)
+
 @pytest.mark.asyncio
 async def test_group_subscribers_public(loop):
     async with loop.new_session() as a, loop.new_session() as b:
@@ -213,6 +234,34 @@ async def test_group_topic_public(loop):
         assert topics[name1] == 'first_topic'
         assert topics[name2] == 'second_topic'
 
+@pytest.mark.asyncio
+async def test_update_profile(loop):
+    async with loop.new_session() as s, loop.new_session() as q:
+        await s.register(random_secret(), public=simple_encode('hello'))
+        await q.register(random_secret())
+
+        topic_name = await s.new_topic()
+        await q.subscribe(topic_name)
+
+        profile = await s.get_profile()
+        assert simple_decode(profile.public) == 'hello'
+        topic_desc = await q.get_topic_description(s.user_id)
+        assert simple_decode(topic_desc.public) == 'hello'
+        [subscriber] = [u for u in (await s.get_subscribed_users(topic_name)) if u.public]
+        assert simple_decode(subscriber.public) == 'hello'
+        [subscriber] = [u for u in (await q.get_subscribed_users(topic_name)) if u.public]
+        assert simple_decode(subscriber.public) == 'hello'
+
+        await s.set_profile(public=simple_encode('world'))
+        profile = await s.get_profile()
+        assert simple_decode(profile.public) == 'world'
+        topic_desc = await q.get_topic_description(s.user_id)
+        assert simple_decode(topic_desc.public) == 'world'
+        [subscriber] = [u for u in (await s.get_subscribed_users(topic_name)) if u.public]
+        assert simple_decode(subscriber.public) == 'world'
+        [subscriber] = [u for u in (await q.get_subscribed_users(topic_name)) if u.public]
+        assert simple_decode(subscriber.public) == 'world'
+
 @pytest.mark.asyncio
 async def test_p2p_topic_last_message_timestamp(loop):
     async with loop.new_session() as s:
